@@ -66,6 +66,26 @@ def wait_for_job(
     )
 
 
+def wait_for_running_job_to_succeed(
+    job_name,
+    namespace,
+    instance=None,
+    run_id=None,
+    wait_timeout=DEFAULT_WAIT_TIMEOUT,
+    wait_time_between_attempts=DEFAULT_WAIT_BETWEEN_ATTEMPTS,
+    num_pods_to_wait_for=DEFAULT_JOB_POD_COUNT,
+):
+    return DagsterKubernetesClient.production_client().wait_for_running_job_to_succeed(
+        job_name,
+        namespace,
+        instance,
+        run_id,
+        wait_timeout,
+        wait_time_between_attempts,
+        num_pods_to_wait_for,
+    )
+
+
 def wait_for_pod(
     pod_name,
     namespace,
